Vespa for Data Scientists
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Motivation

This library contains application specific code related to data
manipulation and analysis of different Vespa use cases. The [Vespa
python API](https://pyvespa.readthedocs.io/) is used to interact with
Vespa applications from python for faster exploration.

The main goal of this space is to facilitate prototyping and
experimentation for data scientists. Please visit Vespa [sample
apps](https://github.com/vespa-engine/sample-apps/) for
producuction-ready use cases and [Vespa docs](https://docs.vespa.ai/)
for in-depth Vespa documentation.

## Install

Code to support and reproduce the usecases documented here can be found
in the `learntorank` library.

Install via PyPI:

`pip install learntorank`
